diff --git a/.github/CODEOWNERS b/.github/CODEOWNERS
index 7c34266..643492d 100644
--- a/.github/CODEOWNERS
+++ b/.github/CODEOWNERS
@@ -1,2 +1,2 @@
-* @LabsDevelopment/boyfriend
-/docs/ @LabsDevelopment/boyfriend-docs
+* @LabsDevelopment/octobot
+/docs/ @LabsDevelopment/octobot-docs
diff --git a/.github/workflows/build-pr.yml b/.github/workflows/build-pr.yml
index c806834..512089c 100644
--- a/.github/workflows/build-pr.yml
+++ b/.github/workflows/build-pr.yml
@@ -25,7 +25,7 @@ jobs:
- name: ReSharper CLI InspectCode
uses: muno92/resharper_inspectcode@1.8.3
with:
- solutionPath: ./Boyfriend.sln
+ solutionPath: ./Octobot.sln
ignoreIssueType: InvertIf, ConvertIfStatementToSwitchStatement
extensions: ReSharperPlugin.CognitiveComplexity
solutionWideAnalysis: true
diff --git a/.github/workflows/build-push.yml b/.github/workflows/build-push.yml
index 13597b2..a757eb2 100644
--- a/.github/workflows/build-push.yml
+++ b/.github/workflows/build-push.yml
@@ -9,7 +9,7 @@ on:
jobs:
upload-solution:
- name: Upload Boyfriend to production
+ name: Upload Octobot to production
runs-on: ubuntu-latest
permissions:
actions: read
diff --git a/Boyfriend.csproj b/Octobot.csproj
similarity index 67%
rename from Boyfriend.csproj
rename to Octobot.csproj
index b99a311..2c5b16b 100644
--- a/Boyfriend.csproj
+++ b/Octobot.csproj
@@ -6,29 +6,29 @@
enable
enable
2.0.0
-
Boyfriend
+ Octobot
Octol1ttle, mctaylors, neroduckale
AGPLv3
- https://github.com/LabsDevelopment/Boyfriend
- https://github.com/LabsDevelopment/Boyfriend/blob/master/LICENSE
- https://github.com/LabsDevelopment/Boyfriend
+ https://github.com/LabsDevelopment/Octobot
+ https://github.com/LabsDevelopment/Octobot/blob/master/LICENSE
+ https://github.com/LabsDevelopment/Octobot
github
- TeamOctolings
+ LabsDevelopment
en
- A legacy-driven Discord bot written in C#
+ A general-purpose Discord bot for moderation written in C#
-
-
-
-
-
-
-
-
-
-
+
+
+
+
+
+
+
+
+
+
@@ -37,6 +37,6 @@
-
+
diff --git a/Boyfriend.sln b/Octobot.sln
similarity index 83%
rename from Boyfriend.sln
rename to Octobot.sln
index b85c5f6..9dd2b89 100644
--- a/Boyfriend.sln
+++ b/Octobot.sln
@@ -1,6 +1,6 @@
Microsoft Visual Studio Solution File, Format Version 12.00
-Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "Boyfriend", "Boyfriend.csproj", "{9CA7A44F-167C-46D4-923D-88CE71044144}"
+Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "Octobot", "Octobot.csproj", "{9CA7A44F-167C-46D4-923D-88CE71044144}"
EndProject
Global
GlobalSection(SolutionConfigurationPlatforms) = preSolution
diff --git a/docs/CONTRIBUTING.md b/docs/CONTRIBUTING.md
index 602e8de..2a15ef2 100644
--- a/docs/CONTRIBUTING.md
+++ b/docs/CONTRIBUTING.md
@@ -1,6 +1,6 @@
# Contributing Guidelines
-Thank you for showing interest in the development of Boyfriend. We aim to provide a good collaborating environment for
+Thank you for showing interest in the development of Octobot. We aim to provide a good collaborating environment for
everyone involved, and as such have decided to list some of the most important things to keep in mind in the process.
Before starting, please read our [Code of Conduct](CODE_OF_CONDUCT.md)
@@ -29,7 +29,7 @@ While pull requests from unaffiliated contributors are welcome, please note that
internal issues that haven't been published to the issue tracker yet. Reviewing PRs is done on a best-effort basis, so
please be aware that it may take a while before a core maintainer gets around to review your change.
-The [issue tracker](https://github.com/LabsDevelopment/Boyfriend/issues) should provide plenty of issues to start with.
+The [issue tracker](https://github.com/LabsDevelopment/Octobot/issues) should provide plenty of issues to start with.
Make sure to check that an issue you're planning to resolve does not already have people working on it and that there
are no PRs associated with it
@@ -62,7 +62,7 @@ After you're done with your changes and you wish to open the PR, please observe
- Please do not merge `master` continually if there are no conflicts to resolve. We will do this for you when the change
is ready for merge.
-We are highly committed to quality when it comes to Boyfriend. This means that contributions from less experienced
+We are highly committed to quality when it comes to Octobot. This means that contributions from less experienced
community members can take multiple rounds of review to get to a mergeable state. We try our utmost best to never
conflate a person with the code they authored, and to keep the discussion focused on the code at all times. Please
consider our comments and requests a learning experience.
diff --git a/docs/README.md b/docs/README.md
index 381d541..e9ada97 100644
--- a/docs/README.md
+++ b/docs/README.md
@@ -1,12 +1,12 @@
-
+
-![License](https://img.shields.io/github/license/LabsDevelopment/Boyfriend)
-![Workflow Status](https://img.shields.io/github/actions/workflow/status/LabsDevelopment/Boyfriend/.github/workflows/build-push.yml?branch=master&logo=ReSharper)
-![Last Commit](https://img.shields.io/github/last-commit/LabsDevelopment/Boyfriend)
+![License](https://img.shields.io/github/license/LabsDevelopment/Octobot)
+![Workflow Status](https://img.shields.io/github/actions/workflow/status/LabsDevelopment/Octobot/.github/workflows/build-push.yml?branch=master&logo=ReSharper)
+![Last Commit](https://img.shields.io/github/last-commit/LabsDevelopment/Octobot)
-Beep! I'm a general-purpose bot for moderation written by [@Octol1ttle](https://github.com/Octol1ttle) in C# and Remora.Discord
+Veemo! I'm a general-purpose bot for moderation (formerly known as Boyfriend) written by [Labs Development Team](https://github.com/LabsDevelopment) in C# and Remora.Discord
## Features
@@ -17,9 +17,9 @@ Beep! I'm a general-purpose bot for moderation written by [@Octol1ttle](https://
*...and more!*
-## Installing and running Boyfriend
+## Installing and running Octobot
-You can read our [wiki](https://github.com/LabsDevelopment/Boyfriend/wiki) in order to assemble your Boyfriend™ and
+You can read our [wiki](https://github.com/LabsDevelopment/Octobot/wiki) in order to assemble your Octobot and
moderate the server.
## Contributing
@@ -33,8 +33,11 @@ the most effective way possible.
![JetBrains Logo (Main) logo](https://resources.jetbrains.com/storage/products/company/brand/logos/jb_beam.svg)
[JetBrains](https://www.jetbrains.com/), creators of [ReSharper](https://www.jetbrains.com/resharper)
-and [Rider](https://www.jetbrains.com/rider), supports Boyfriend with one of
+and [Rider](https://www.jetbrains.com/rider), supports Octobot with one of
their [Open Source Licenses](https://jb.gg/OpenSourceSupport).
-Rider is the recommended IDE when working with Boyfriend, and everyone on the Boyfriend team uses it.
+Rider is the recommended IDE when working with Octobot, and everyone on the Octobot team uses it.
Additionally, ReSharper command-line tools made by JetBrains are used for status checks on pull requests to ensure code
quality even when not using ReSharper or Rider.
+
+#
+Not an official Splatoon™ product. We are in no way affiliated with or endorsed by Nintendo Company, or other rightsholders.
diff --git a/docs/assets/boyfriend.png b/docs/assets/boyfriend.png
deleted file mode 100644
index a8a5d16..0000000
Binary files a/docs/assets/boyfriend.png and /dev/null differ
diff --git a/locale/Messages.resx b/locale/Messages.resx
index 4d84198..7b9a471 100644
--- a/locale/Messages.resx
+++ b/locale/Messages.resx
@@ -120,14 +120,14 @@
{0}, welcome to {1}
-
- Bah!
+
+ Veemo!
-
- Bop!
+
+ Woomy!
-
- Beep!
+
+ Ngyes!
I do not have permission to execute this command!
@@ -520,13 +520,13 @@
Developers:
- Boyfriend's source code
+ Octobot's source code
- About Boyfriend
+ About Octobot
- developer & designer, Boyfriend's Wiki creator
+ developer & designer, Octobot's Wiki creator
main developer
@@ -544,7 +544,7 @@
You asked me to remind you {0}
- Boyfriend's Settings
+ Octobot's Settings
Setting successfully changed
diff --git a/locale/Messages.ru.resx b/locale/Messages.ru.resx
index 4900e53..3e31f8f 100644
--- a/locale/Messages.ru.resx
+++ b/locale/Messages.ru.resx
@@ -120,14 +120,14 @@
{0}, добро пожаловать на сервер {1}
-
- Бап!
+
+ Виимо!
-
- Боп!
+
+ Вууми!
-
- Бип!
+
+ Нгьес!
У меня недостаточно прав для выполнения этой команды!
@@ -520,10 +520,10 @@
Разработчики:
- Исходный код Boyfriend
+ Исходный код Octobot
- О Boyfriend
+ Об Octobot
разработчик
@@ -532,7 +532,7 @@
основной разработчик
- разработчик и дизайнер, создатель Boyfriend's Wiki
+ разработчик и дизайнер, создатель Octobot's Wiki
Напоминание для {0} создано
@@ -544,7 +544,7 @@
Вы просили напомнить вам {0}
- Настройки Boyfriend
+ Настройки Octobot
Настройка успешно изменена
diff --git a/locale/Messages.tt-ru.resx b/locale/Messages.tt-ru.resx
index 5a08755..df98622 100644
--- a/locale/Messages.tt-ru.resx
+++ b/locale/Messages.tt-ru.resx
@@ -120,14 +120,14 @@
{0}, добро пожаловать на сервер {1}
-
- брах!
+
+ вииимо!
-
- брох!
+
+ вуууми!
-
- брух!
+
+ нгьес!
у меня прав нету, сделай что нибудь.
@@ -520,13 +520,13 @@
девелоперы:
- репа Boyfriend (тык)
+ репа Octobot (тык)
- немного о Boyfriend
+ немного об Octobot
- скучный девелопер + дизайнер создавший Boyfriend's Wiki
+ скучный девелопер + дизайнер создавший Octobot's Wiki
ВАЖНЫЙ соучастник кодинг-стримов @Octol1ttle
@@ -544,7 +544,7 @@
ты хотел чтоб я напомнил тебе {0}
- приколы Boyfriend
+ приколы Octobot
прикол редактирован
diff --git a/src/ColorsList.cs b/src/ColorsList.cs
index fc32274..cd40313 100644
--- a/src/ColorsList.cs
+++ b/src/ColorsList.cs
@@ -1,6 +1,6 @@
using System.Drawing;
-namespace Boyfriend;
+namespace Octobot;
///
/// Contains all colors used in embeds.
diff --git a/src/Commands/AboutCommandGroup.cs b/src/Commands/AboutCommandGroup.cs
index e9d9874..c6a6ed3 100644
--- a/src/Commands/AboutCommandGroup.cs
+++ b/src/Commands/AboutCommandGroup.cs
@@ -1,8 +1,8 @@
using System.ComponentModel;
using System.Text;
-using Boyfriend.Data;
-using Boyfriend.Services;
using JetBrains.Annotations;
+using Octobot.Data;
+using Octobot.Services;
using Remora.Commands.Attributes;
using Remora.Commands.Groups;
using Remora.Discord.API.Abstractions.Objects;
@@ -15,7 +15,7 @@ using Remora.Discord.Extensions.Embeds;
using Remora.Rest.Core;
using Remora.Results;
-namespace Boyfriend.Commands;
+namespace Octobot.Commands;
///
/// Handles the command to show information about this bot: /about.
@@ -57,7 +57,7 @@ public class AboutCommandGroup : CommandGroup
[Command("about")]
[DiscordDefaultDMPermission(false)]
[RequireContext(ChannelContext.Guild)]
- [Description("Shows Boyfriend's developers")]
+ [Description("Shows Octobot's developers")]
[UsedImplicitly]
public async Task ExecuteAboutAsync()
{
@@ -90,12 +90,12 @@ public class AboutCommandGroup : CommandGroup
builder.AppendLine($"- {tag} — {$"AboutDeveloper@{dev.Username}".Localized()}");
}
- builder.Append($"### [{Messages.AboutTitleRepository}](https://github.com/LabsDevelopment/Boyfriend)");
+ builder.Append($"### [{Messages.AboutTitleRepository}](https://github.com/LabsDevelopment/Octobot)");
var embed = new EmbedBuilder().WithSmallTitle(Messages.AboutBot, currentUser)
.WithDescription(builder.ToString())
.WithColour(ColorsList.Cyan)
- .WithImageUrl("https://mctaylors.ddns.net/cdn/boyfriend-banner-light.png")
+ .WithImageUrl("https://mctaylors.ddns.net/cdn/octobot-banner.png")
.Build();
return await _feedback.SendContextualEmbedResultAsync(embed, ct);
diff --git a/src/Commands/BanCommandGroup.cs b/src/Commands/BanCommandGroup.cs
index 0ac5a36..a76e79c 100644
--- a/src/Commands/BanCommandGroup.cs
+++ b/src/Commands/BanCommandGroup.cs
@@ -1,9 +1,9 @@
using System.ComponentModel;
using System.Text;
-using Boyfriend.Data;
-using Boyfriend.Services;
-using Boyfriend.Services.Update;
using JetBrains.Annotations;
+using Octobot.Data;
+using Octobot.Services;
+using Octobot.Services.Update;
using Remora.Commands.Attributes;
using Remora.Commands.Groups;
using Remora.Discord.API.Abstractions.Objects;
@@ -17,7 +17,7 @@ using Remora.Discord.Extensions.Formatting;
using Remora.Rest.Core;
using Remora.Results;
-namespace Boyfriend.Commands;
+namespace Octobot.Commands;
///
/// Handles commands related to ban management: /ban and /unban.
diff --git a/src/Commands/Events/ErrorLoggingPostExecutionEvent.cs b/src/Commands/Events/ErrorLoggingPostExecutionEvent.cs
index b0fbccf..9000267 100644
--- a/src/Commands/Events/ErrorLoggingPostExecutionEvent.cs
+++ b/src/Commands/Events/ErrorLoggingPostExecutionEvent.cs
@@ -4,7 +4,7 @@ using Remora.Discord.Commands.Contexts;
using Remora.Discord.Commands.Services;
using Remora.Results;
-namespace Boyfriend.Commands.Events;
+namespace Octobot.Commands.Events;
///
/// Handles error logging for slash command groups.
diff --git a/src/Commands/Events/LoggingPreparationErrorEvent.cs b/src/Commands/Events/LoggingPreparationErrorEvent.cs
index 6d80513..b3f9425 100644
--- a/src/Commands/Events/LoggingPreparationErrorEvent.cs
+++ b/src/Commands/Events/LoggingPreparationErrorEvent.cs
@@ -4,7 +4,7 @@ using Remora.Discord.Commands.Contexts;
using Remora.Discord.Commands.Services;
using Remora.Results;
-namespace Boyfriend.Commands.Events;
+namespace Octobot.Commands.Events;
///
/// Handles error logging for slash commands that couldn't be successfully prepared.
diff --git a/src/Commands/KickCommandGroup.cs b/src/Commands/KickCommandGroup.cs
index c3a4179..f69103d 100644
--- a/src/Commands/KickCommandGroup.cs
+++ b/src/Commands/KickCommandGroup.cs
@@ -1,7 +1,7 @@
using System.ComponentModel;
-using Boyfriend.Data;
-using Boyfriend.Services;
using JetBrains.Annotations;
+using Octobot.Data;
+using Octobot.Services;
using Remora.Commands.Attributes;
using Remora.Commands.Groups;
using Remora.Discord.API.Abstractions.Objects;
@@ -14,7 +14,7 @@ using Remora.Discord.Extensions.Embeds;
using Remora.Rest.Core;
using Remora.Results;
-namespace Boyfriend.Commands;
+namespace Octobot.Commands;
///
/// Handles the command to kick members of a guild: /kick.
diff --git a/src/Commands/MuteCommandGroup.cs b/src/Commands/MuteCommandGroup.cs
index 5b3b68d..33e8a9f 100644
--- a/src/Commands/MuteCommandGroup.cs
+++ b/src/Commands/MuteCommandGroup.cs
@@ -1,9 +1,9 @@
using System.ComponentModel;
using System.Text;
-using Boyfriend.Data;
-using Boyfriend.Services;
-using Boyfriend.Services.Update;
using JetBrains.Annotations;
+using Octobot.Data;
+using Octobot.Services;
+using Octobot.Services.Update;
using Remora.Commands.Attributes;
using Remora.Commands.Groups;
using Remora.Discord.API.Abstractions.Objects;
@@ -17,7 +17,7 @@ using Remora.Discord.Extensions.Formatting;
using Remora.Rest.Core;
using Remora.Results;
-namespace Boyfriend.Commands;
+namespace Octobot.Commands;
///
/// Handles commands related to mute management: /mute and /unmute.
diff --git a/src/Commands/RemindCommandGroup.cs b/src/Commands/RemindCommandGroup.cs
index d150e9c..cead86e 100644
--- a/src/Commands/RemindCommandGroup.cs
+++ b/src/Commands/RemindCommandGroup.cs
@@ -1,8 +1,8 @@
using System.ComponentModel;
using System.Text;
-using Boyfriend.Data;
-using Boyfriend.Services;
using JetBrains.Annotations;
+using Octobot.Data;
+using Octobot.Services;
using Remora.Commands.Attributes;
using Remora.Commands.Groups;
using Remora.Discord.API.Abstractions.Objects;
@@ -16,7 +16,7 @@ using Remora.Discord.Extensions.Formatting;
using Remora.Rest.Core;
using Remora.Results;
-namespace Boyfriend.Commands;
+namespace Octobot.Commands;
///
/// Handles commands to manage reminders: /remind, /listremind, /delremind
diff --git a/src/Commands/SettingsCommandGroup.cs b/src/Commands/SettingsCommandGroup.cs
index 50ea955..9f7c3df 100644
--- a/src/Commands/SettingsCommandGroup.cs
+++ b/src/Commands/SettingsCommandGroup.cs
@@ -1,10 +1,10 @@
using System.ComponentModel;
using System.Text;
using System.Text.Json.Nodes;
-using Boyfriend.Data;
-using Boyfriend.Data.Options;
-using Boyfriend.Services;
using JetBrains.Annotations;
+using Octobot.Data;
+using Octobot.Data.Options;
+using Octobot.Services;
using Remora.Commands.Attributes;
using Remora.Commands.Groups;
using Remora.Discord.API.Abstractions.Objects;
@@ -18,7 +18,7 @@ using Remora.Discord.Extensions.Formatting;
using Remora.Rest.Core;
using Remora.Results;
-namespace Boyfriend.Commands;
+namespace Octobot.Commands;
///
/// Handles the commands to list and modify per-guild settings: /settings and /settings list.
diff --git a/src/Commands/ToolsCommandGroup.cs b/src/Commands/ToolsCommandGroup.cs
index fa0f015..64e6729 100644
--- a/src/Commands/ToolsCommandGroup.cs
+++ b/src/Commands/ToolsCommandGroup.cs
@@ -1,9 +1,9 @@
using System.ComponentModel;
using System.Drawing;
using System.Text;
-using Boyfriend.Data;
-using Boyfriend.Services;
using JetBrains.Annotations;
+using Octobot.Data;
+using Octobot.Services;
using Remora.Commands.Attributes;
using Remora.Commands.Groups;
using Remora.Discord.API.Abstractions.Objects;
@@ -16,7 +16,7 @@ using Remora.Discord.Extensions.Formatting;
using Remora.Rest.Core;
using Remora.Results;
-namespace Boyfriend.Commands;
+namespace Octobot.Commands;
///
/// Handles tool commands: /showinfo, /random.
diff --git a/src/Data/GuildData.cs b/src/Data/GuildData.cs
index 2e14e17..a779b56 100644
--- a/src/Data/GuildData.cs
+++ b/src/Data/GuildData.cs
@@ -1,7 +1,7 @@
using System.Text.Json.Nodes;
using Remora.Rest.Core;
-namespace Boyfriend.Data;
+namespace Octobot.Data;
///
/// Stores information about a guild. This information is not accessible via the Discord API.
diff --git a/src/Data/GuildSettings.cs b/src/Data/GuildSettings.cs
index 1c94835..cdaede6 100644
--- a/src/Data/GuildSettings.cs
+++ b/src/Data/GuildSettings.cs
@@ -1,8 +1,8 @@
-using Boyfriend.Data.Options;
-using Boyfriend.Responders;
+using Octobot.Data.Options;
+using Octobot.Responders;
using Remora.Discord.API.Abstractions.Objects;
-namespace Boyfriend.Data;
+namespace Octobot.Data;
///
/// Contains all per-guild settings that can be set by a member
diff --git a/src/Data/MemberData.cs b/src/Data/MemberData.cs
index 72a9ee1..c7ddc27 100644
--- a/src/Data/MemberData.cs
+++ b/src/Data/MemberData.cs
@@ -1,4 +1,4 @@
-namespace Boyfriend.Data;
+namespace Octobot.Data;
///
/// Stores information about a member
diff --git a/src/Data/Options/AllOptionsEnum.cs b/src/Data/Options/AllOptionsEnum.cs
index d0b1ae7..a96a9ac 100644
--- a/src/Data/Options/AllOptionsEnum.cs
+++ b/src/Data/Options/AllOptionsEnum.cs
@@ -1,7 +1,7 @@
-using Boyfriend.Commands;
using JetBrains.Annotations;
+using Octobot.Commands;
-namespace Boyfriend.Data.Options;
+namespace Octobot.Data.Options;
///
/// Represents all options as enums.
diff --git a/src/Data/Options/BoolOption.cs b/src/Data/Options/BoolOption.cs
index 51cd3a1..130687e 100644
--- a/src/Data/Options/BoolOption.cs
+++ b/src/Data/Options/BoolOption.cs
@@ -1,7 +1,7 @@
using System.Text.Json.Nodes;
using Remora.Results;
-namespace Boyfriend.Data.Options;
+namespace Octobot.Data.Options;
public sealed class BoolOption : Option
{
diff --git a/src/Data/Options/IOption.cs b/src/Data/Options/IOption.cs
index 42138dc..b8ed03c 100644
--- a/src/Data/Options/IOption.cs
+++ b/src/Data/Options/IOption.cs
@@ -1,7 +1,7 @@
using System.Text.Json.Nodes;
using Remora.Results;
-namespace Boyfriend.Data.Options;
+namespace Octobot.Data.Options;
public interface IOption
{
diff --git a/src/Data/Options/LanguageOption.cs b/src/Data/Options/LanguageOption.cs
index a82d7f6..464c61b 100644
--- a/src/Data/Options/LanguageOption.cs
+++ b/src/Data/Options/LanguageOption.cs
@@ -3,7 +3,7 @@ using System.Text.Json.Nodes;
using Remora.Discord.Extensions.Formatting;
using Remora.Results;
-namespace Boyfriend.Data.Options;
+namespace Octobot.Data.Options;
///
public sealed class LanguageOption : Option
diff --git a/src/Data/Options/Option.cs b/src/Data/Options/Option.cs
index a62eb04..0ba8ce1 100644
--- a/src/Data/Options/Option.cs
+++ b/src/Data/Options/Option.cs
@@ -2,7 +2,7 @@ using System.Text.Json.Nodes;
using Remora.Discord.Extensions.Formatting;
using Remora.Results;
-namespace Boyfriend.Data.Options;
+namespace Octobot.Data.Options;
///
/// Represents an per-guild option.
diff --git a/src/Data/Options/SnowflakeOption.cs b/src/Data/Options/SnowflakeOption.cs
index 7391b00..2150725 100644
--- a/src/Data/Options/SnowflakeOption.cs
+++ b/src/Data/Options/SnowflakeOption.cs
@@ -4,7 +4,7 @@ using Remora.Discord.Extensions.Formatting;
using Remora.Rest.Core;
using Remora.Results;
-namespace Boyfriend.Data.Options;
+namespace Octobot.Data.Options;
public sealed partial class SnowflakeOption : Option
{
diff --git a/src/Data/Options/TimeSpanOption.cs b/src/Data/Options/TimeSpanOption.cs
index 5e39cf0..7f60ebb 100644
--- a/src/Data/Options/TimeSpanOption.cs
+++ b/src/Data/Options/TimeSpanOption.cs
@@ -2,7 +2,7 @@ using System.Text.Json.Nodes;
using Remora.Commands.Parsers;
using Remora.Results;
-namespace Boyfriend.Data.Options;
+namespace Octobot.Data.Options;
public sealed class TimeSpanOption : Option
{
diff --git a/src/Data/Reminder.cs b/src/Data/Reminder.cs
index a332003..828fadb 100644
--- a/src/Data/Reminder.cs
+++ b/src/Data/Reminder.cs
@@ -1,4 +1,4 @@
-namespace Boyfriend.Data;
+namespace Octobot.Data;
public struct Reminder
{
diff --git a/src/Data/ScheduledEventData.cs b/src/Data/ScheduledEventData.cs
index f03daee..59efc63 100644
--- a/src/Data/ScheduledEventData.cs
+++ b/src/Data/ScheduledEventData.cs
@@ -1,7 +1,7 @@
using System.Text.Json.Serialization;
using Remora.Discord.API.Abstractions.Objects;
-namespace Boyfriend.Data;
+namespace Octobot.Data;
///
/// Stores information about scheduled events. This information is not provided by the Discord API.
diff --git a/src/Extensions.cs b/src/Extensions.cs
index c06c4ce..511ab85 100644
--- a/src/Extensions.cs
+++ b/src/Extensions.cs
@@ -13,7 +13,7 @@ using Remora.Discord.Extensions.Formatting;
using Remora.Rest.Core;
using Remora.Results;
-namespace Boyfriend;
+namespace Octobot;
public static class Extensions
{
diff --git a/src/InteractionResponders.cs b/src/InteractionResponders.cs
index d3916b0..8e42110 100644
--- a/src/InteractionResponders.cs
+++ b/src/InteractionResponders.cs
@@ -5,7 +5,7 @@ using Remora.Discord.Commands.Feedback.Services;
using Remora.Discord.Interactivity;
using Remora.Results;
-namespace Boyfriend;
+namespace Octobot;
///
/// Handles responding to various interactions.
diff --git a/src/Messages.Designer.cs b/src/Messages.Designer.cs
index ae712df..3c2c747 100644
--- a/src/Messages.Designer.cs
+++ b/src/Messages.Designer.cs
@@ -7,7 +7,7 @@
//
//------------------------------------------------------------------------------
-namespace Boyfriend {
+namespace Octobot {
[System.CodeDom.Compiler.GeneratedCodeAttribute("System.Resources.Tools.StronglyTypedResourceBuilder", "4.0.0.0")]
[System.Diagnostics.DebuggerNonUserCodeAttribute()]
[System.Runtime.CompilerServices.CompilerGeneratedAttribute()]
@@ -25,7 +25,7 @@ namespace Boyfriend {
internal static System.Resources.ResourceManager ResourceManager {
get {
if (object.Equals(null, resourceMan)) {
- System.Resources.ResourceManager temp = new System.Resources.ResourceManager("Boyfriend.locale.Messages", typeof(Messages).Assembly);
+ System.Resources.ResourceManager temp = new System.Resources.ResourceManager("Octobot.locale.Messages", typeof(Messages).Assembly);
resourceMan = temp;
}
return resourceMan;
@@ -72,21 +72,21 @@ namespace Boyfriend {
}
}
- internal static string Beep1 {
+ internal static string Sound1 {
get {
- return ResourceManager.GetString("Beep1", resourceCulture);
+ return ResourceManager.GetString("Sound1", resourceCulture);
}
}
- internal static string Beep2 {
+ internal static string Sound2 {
get {
- return ResourceManager.GetString("Beep2", resourceCulture);
+ return ResourceManager.GetString("Sound2", resourceCulture);
}
}
- internal static string Beep3 {
+ internal static string Sound3 {
get {
- return ResourceManager.GetString("Beep3", resourceCulture);
+ return ResourceManager.GetString("Sound3", resourceCulture);
}
}
diff --git a/src/Boyfriend.cs b/src/Octobot.cs
similarity index 95%
rename from src/Boyfriend.cs
rename to src/Octobot.cs
index 4ba43f8..662d1bf 100644
--- a/src/Boyfriend.cs
+++ b/src/Octobot.cs
@@ -1,11 +1,11 @@
-using Boyfriend.Commands;
-using Boyfriend.Commands.Events;
-using Boyfriend.Services;
-using Boyfriend.Services.Update;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Hosting;
using Microsoft.Extensions.Logging;
+using Octobot.Commands;
+using Octobot.Commands.Events;
+using Octobot.Services;
+using Octobot.Services.Update;
using Remora.Commands.Extensions;
using Remora.Discord.API.Abstractions.Gateway.Commands;
using Remora.Discord.API.Abstractions.Objects;
@@ -21,9 +21,9 @@ using Remora.Discord.Interactivity.Extensions;
using Remora.Rest.Core;
using Serilog.Extensions.Logging;
-namespace Boyfriend;
+namespace Octobot;
-public sealed class Boyfriend
+public sealed class Octobot
{
public static readonly AllowedMentions NoMentions = new(
Array.Empty(), Array.Empty(), Array.Empty());
@@ -104,7 +104,7 @@ public sealed class Boyfriend
.WithCommandGroup()
.WithCommandGroup()
.WithCommandGroup();
- var responderTypes = typeof(Boyfriend).Assembly
+ var responderTypes = typeof(Octobot).Assembly
.GetExportedTypes()
.Where(t => t.IsResponder());
foreach (var responderType in responderTypes)
@@ -114,7 +114,7 @@ public sealed class Boyfriend
}
).ConfigureLogging(
c => c.AddConsole()
- .AddFile("Logs/Boyfriend-{Date}.log",
+ .AddFile("Logs/Octobot-{Date}.log",
outputTemplate: "{Timestamp:o} [{Level:u4}] {Message} {NewLine}{Exception}")
.AddFilter("System.Net.Http.HttpClient.*.LogicalHandler", LogLevel.Warning)
.AddFilter("System.Net.Http.HttpClient.*.ClientHandler", LogLevel.Warning)
diff --git a/src/Responders/GuildLoadedResponder.cs b/src/Responders/GuildLoadedResponder.cs
index b3288c0..a6b44dd 100644
--- a/src/Responders/GuildLoadedResponder.cs
+++ b/src/Responders/GuildLoadedResponder.cs
@@ -1,7 +1,7 @@
-using Boyfriend.Data;
-using Boyfriend.Services;
using JetBrains.Annotations;
using Microsoft.Extensions.Logging;
+using Octobot.Data;
+using Octobot.Services;
using Remora.Discord.API.Abstractions.Gateway.Events;
using Remora.Discord.API.Abstractions.Rest;
using Remora.Discord.API.Gateway.Events;
@@ -9,7 +9,7 @@ using Remora.Discord.Extensions.Embeds;
using Remora.Discord.Gateway.Responders;
using Remora.Results;
-namespace Boyfriend.Responders;
+namespace Octobot.Responders;
///
/// Handles sending a message to a guild that has just initialized if that guild
@@ -85,7 +85,7 @@ public class GuildLoadedResponder : IResponder
var i = Random.Shared.Next(1, 4);
var embed = new EmbedBuilder().WithSmallTitle(currentUser.GetTag(), currentUser)
- .WithTitle($"Beep{i}".Localized())
+ .WithTitle($"Sound{i}".Localized())
.WithDescription(Messages.Ready)
.WithCurrentTimestamp()
.WithColour(ColorsList.Blue)
diff --git a/src/Responders/GuildMemberJoinedResponder.cs b/src/Responders/GuildMemberJoinedResponder.cs
index 849ff5e..57bd01f 100644
--- a/src/Responders/GuildMemberJoinedResponder.cs
+++ b/src/Responders/GuildMemberJoinedResponder.cs
@@ -1,7 +1,7 @@
using System.Text.Json.Nodes;
-using Boyfriend.Data;
-using Boyfriend.Services;
using JetBrains.Annotations;
+using Octobot.Data;
+using Octobot.Services;
using Remora.Discord.API.Abstractions.Gateway.Events;
using Remora.Discord.API.Abstractions.Rest;
using Remora.Discord.Extensions.Embeds;
@@ -9,7 +9,7 @@ using Remora.Discord.Gateway.Responders;
using Remora.Rest.Core;
using Remora.Results;
-namespace Boyfriend.Responders;
+namespace Octobot.Responders;
///
/// Handles sending a guild's if one is set.
@@ -78,7 +78,7 @@ public class GuildMemberJoinedResponder : IResponder
return (Result)await _channelApi.CreateMessageAsync(
GuildSettings.PublicFeedbackChannel.Get(cfg), embeds: new[] { built },
- allowedMentions: Boyfriend.NoMentions, ct: ct);
+ allowedMentions: Octobot.NoMentions, ct: ct);
}
private async Task TryReturnRolesAsync(
diff --git a/src/Responders/GuildMemberRolesUpdatedResponder.cs b/src/Responders/GuildMemberRolesUpdatedResponder.cs
index eade781..b883c89 100644
--- a/src/Responders/GuildMemberRolesUpdatedResponder.cs
+++ b/src/Responders/GuildMemberRolesUpdatedResponder.cs
@@ -1,11 +1,11 @@
-using Boyfriend.Data;
-using Boyfriend.Services;
using JetBrains.Annotations;
+using Octobot.Data;
+using Octobot.Services;
using Remora.Discord.API.Abstractions.Gateway.Events;
using Remora.Discord.Gateway.Responders;
using Remora.Results;
-namespace Boyfriend.Responders;
+namespace Octobot.Responders;
///
/// Handles updating when a guild member is updated.
diff --git a/src/Responders/MessageDeletedResponder.cs b/src/Responders/MessageDeletedResponder.cs
index 8ae2418..ae92770 100644
--- a/src/Responders/MessageDeletedResponder.cs
+++ b/src/Responders/MessageDeletedResponder.cs
@@ -1,7 +1,7 @@
using System.Text;
-using Boyfriend.Data;
-using Boyfriend.Services;
using JetBrains.Annotations;
+using Octobot.Data;
+using Octobot.Services;
using Remora.Discord.API.Abstractions.Gateway.Events;
using Remora.Discord.API.Abstractions.Objects;
using Remora.Discord.API.Abstractions.Rest;
@@ -10,7 +10,7 @@ using Remora.Discord.Extensions.Formatting;
using Remora.Discord.Gateway.Responders;
using Remora.Results;
-namespace Boyfriend.Responders;
+namespace Octobot.Responders;
///
/// Handles logging the contents of a deleted message and the user who deleted the message
@@ -104,6 +104,6 @@ public class MessageDeletedResponder : IResponder
return (Result)await _channelApi.CreateMessageAsync(
GuildSettings.PrivateFeedbackChannel.Get(cfg), embeds: new[] { built },
- allowedMentions: Boyfriend.NoMentions, ct: ct);
+ allowedMentions: Octobot.NoMentions, ct: ct);
}
}
diff --git a/src/Responders/MessageEditedResponder.cs b/src/Responders/MessageEditedResponder.cs
index d7e2347..5e2084c 100644
--- a/src/Responders/MessageEditedResponder.cs
+++ b/src/Responders/MessageEditedResponder.cs
@@ -1,8 +1,8 @@
using System.Text;
-using Boyfriend.Data;
-using Boyfriend.Services;
using DiffPlex.DiffBuilder;
using JetBrains.Annotations;
+using Octobot.Data;
+using Octobot.Services;
using Remora.Discord.API.Abstractions.Gateway.Events;
using Remora.Discord.API.Abstractions.Objects;
using Remora.Discord.API.Abstractions.Rest;
@@ -12,7 +12,7 @@ using Remora.Discord.Extensions.Embeds;
using Remora.Discord.Gateway.Responders;
using Remora.Results;
-namespace Boyfriend.Responders;
+namespace Octobot.Responders;
///
/// Handles logging the difference between an edited message's old and new content
@@ -112,6 +112,6 @@ public class MessageEditedResponder : IResponder
return (Result)await _channelApi.CreateMessageAsync(
GuildSettings.PrivateFeedbackChannel.Get(cfg), embeds: new[] { built },
- allowedMentions: Boyfriend.NoMentions, ct: ct);
+ allowedMentions: Octobot.NoMentions, ct: ct);
}
}
diff --git a/src/Responders/MessageReceivedResponder.cs b/src/Responders/MessageReceivedResponder.cs
index cadef5f..f5c65f4 100644
--- a/src/Responders/MessageReceivedResponder.cs
+++ b/src/Responders/MessageReceivedResponder.cs
@@ -5,7 +5,7 @@ using Remora.Discord.Gateway.Responders;
using Remora.Rest.Core;
using Remora.Results;
-namespace Boyfriend.Responders;
+namespace Octobot.Responders;
///
/// Handles sending replies to easter egg messages.
diff --git a/src/Responders/ScheduledEventCreatedResponder.cs b/src/Responders/ScheduledEventCreatedResponder.cs
index 3541237..4d87b6c 100644
--- a/src/Responders/ScheduledEventCreatedResponder.cs
+++ b/src/Responders/ScheduledEventCreatedResponder.cs
@@ -1,11 +1,11 @@
-using Boyfriend.Data;
-using Boyfriend.Services;
using JetBrains.Annotations;
+using Octobot.Data;
+using Octobot.Services;
using Remora.Discord.API.Abstractions.Gateway.Events;
using Remora.Discord.Gateway.Responders;
using Remora.Results;
-namespace Boyfriend.Responders;
+namespace Octobot.Responders;
///
/// Handles adding a scheduled event to a guild's ScheduledEventData.
diff --git a/src/Responders/ScheduledEventUpdatedResponder.cs b/src/Responders/ScheduledEventUpdatedResponder.cs
index 7db7edd..85162a4 100644
--- a/src/Responders/ScheduledEventUpdatedResponder.cs
+++ b/src/Responders/ScheduledEventUpdatedResponder.cs
@@ -1,10 +1,10 @@
-using Boyfriend.Services;
using JetBrains.Annotations;
+using Octobot.Services;
using Remora.Discord.API.Abstractions.Gateway.Events;
using Remora.Discord.Gateway.Responders;
using Remora.Results;
-namespace Boyfriend.Responders;
+namespace Octobot.Responders;
[UsedImplicitly]
public class ScheduledEventUpdatedResponder : IResponder
diff --git a/src/Services/BackgroundGuildDataSaverService.cs b/src/Services/BackgroundGuildDataSaverService.cs
index 76a7ddb..766ffe0 100644
--- a/src/Services/BackgroundGuildDataSaverService.cs
+++ b/src/Services/BackgroundGuildDataSaverService.cs
@@ -1,6 +1,6 @@
using Microsoft.Extensions.Hosting;
-namespace Boyfriend.Services;
+namespace Octobot.Services;
public sealed class BackgroundGuildDataSaverService : BackgroundService
{
diff --git a/src/Services/GuildDataService.cs b/src/Services/GuildDataService.cs
index 0833adf..5d2b1b1 100644
--- a/src/Services/GuildDataService.cs
+++ b/src/Services/GuildDataService.cs
@@ -1,13 +1,13 @@
using System.Collections.Concurrent;
using System.Text.Json;
using System.Text.Json.Nodes;
-using Boyfriend.Data;
using Microsoft.Extensions.Hosting;
using Microsoft.Extensions.Logging;
+using Octobot.Data;
using Remora.Discord.API.Abstractions.Rest;
using Remora.Rest.Core;
-namespace Boyfriend.Services;
+namespace Octobot.Services;
///
/// Handles saving, loading, initializing and providing .
diff --git a/src/Services/Update/MemberUpdateService.cs b/src/Services/Update/MemberUpdateService.cs
index 3db307d..7cd13fe 100644
--- a/src/Services/Update/MemberUpdateService.cs
+++ b/src/Services/Update/MemberUpdateService.cs
@@ -1,7 +1,7 @@
using System.Text.RegularExpressions;
-using Boyfriend.Data;
using Microsoft.Extensions.Hosting;
using Microsoft.Extensions.Logging;
+using Octobot.Data;
using Remora.Discord.API.Abstractions.Objects;
using Remora.Discord.API.Abstractions.Rest;
using Remora.Discord.Extensions.Embeds;
@@ -9,7 +9,7 @@ using Remora.Discord.Extensions.Formatting;
using Remora.Rest.Core;
using Remora.Results;
-namespace Boyfriend.Services.Update;
+namespace Octobot.Services.Update;
public sealed partial class MemberUpdateService : BackgroundService
{
diff --git a/src/Services/Update/ScheduledEventUpdateService.cs b/src/Services/Update/ScheduledEventUpdateService.cs
index de03fc5..85d532a 100644
--- a/src/Services/Update/ScheduledEventUpdateService.cs
+++ b/src/Services/Update/ScheduledEventUpdateService.cs
@@ -1,7 +1,7 @@
using System.Text.Json.Nodes;
-using Boyfriend.Data;
using Microsoft.Extensions.Hosting;
using Microsoft.Extensions.Logging;
+using Octobot.Data;
using Remora.Discord.API.Abstractions.Objects;
using Remora.Discord.API.Abstractions.Rest;
using Remora.Discord.API.Objects;
@@ -11,7 +11,7 @@ using Remora.Discord.Interactivity;
using Remora.Rest.Core;
using Remora.Results;
-namespace Boyfriend.Services.Update;
+namespace Octobot.Services.Update;
public sealed class ScheduledEventUpdateService : BackgroundService
{
diff --git a/src/Services/Update/SongUpdateService.cs b/src/Services/Update/SongUpdateService.cs
index 70a2d70..5102fbf 100644
--- a/src/Services/Update/SongUpdateService.cs
+++ b/src/Services/Update/SongUpdateService.cs
@@ -4,7 +4,7 @@ using Remora.Discord.API.Gateway.Commands;
using Remora.Discord.API.Objects;
using Remora.Discord.Gateway;
-namespace Boyfriend.Services.Update;
+namespace Octobot.Services.Update;
public sealed class SongUpdateService : BackgroundService
{
diff --git a/src/Services/UtilityService.cs b/src/Services/UtilityService.cs
index 35a11dd..bc4ce35 100644
--- a/src/Services/UtilityService.cs
+++ b/src/Services/UtilityService.cs
@@ -1,8 +1,8 @@
using System.Drawing;
using System.Text;
using System.Text.Json.Nodes;
-using Boyfriend.Data;
using Microsoft.Extensions.Hosting;
+using Octobot.Data;
using Remora.Discord.API.Abstractions.Objects;
using Remora.Discord.API.Abstractions.Rest;
using Remora.Discord.Extensions.Embeds;
@@ -10,7 +10,7 @@ using Remora.Discord.Extensions.Formatting;
using Remora.Rest.Core;
using Remora.Results;
-namespace Boyfriend.Services;
+namespace Octobot.Services;
///
/// Provides utility methods that cannot be transformed to extension methods because they require usage
diff --git a/src/Commands/ClearCommandGroup.cs b/src/Commands/ClearCommandGroup.cs
index f9ac630..e6c08f3 100644
--- a/src/Commands/ClearCommandGroup.cs
+++ b/src/Commands/ClearCommandGroup.cs
@@ -1,8 +1,8 @@
using System.ComponentModel;
using System.Text;
-using Boyfriend.Data;
-using Boyfriend.Services;
using JetBrains.Annotations;
+using Octobot.Data;
+using Octobot.Services;
using Remora.Commands.Attributes;
using Remora.Commands.Groups;
using Remora.Discord.API.Abstractions.Objects;
@@ -16,7 +16,7 @@ using Remora.Discord.Extensions.Formatting;
using Remora.Rest.Core;
using Remora.Results;
-namespace Boyfriend.Commands;
+namespace Octobot.Commands;
///
/// Handles the command to clear messages in a channel: /clear.
@@ -100,7 +100,7 @@ public class ClearCommandGroup : CommandGroup
{
var idList = new List(messages.Count);
var builder = new StringBuilder().AppendLine(Mention.Channel(channelId)).AppendLine();
- for (var i = messages.Count - 1; i >= 1; i--) // '>= 1' to skip last message ('Boyfriend is thinking...')
+ for (var i = messages.Count - 1; i >= 1; i--) // '>= 1' to skip last message ('Octobot is thinking...')
{
var message = messages[i];
idList.Add(message.ID);
diff --git a/src/Commands/PingCommandGroup.cs b/src/Commands/PingCommandGroup.cs
index e52f22c..07851a7 100644
--- a/src/Commands/PingCommandGroup.cs
+++ b/src/Commands/PingCommandGroup.cs
@@ -1,7 +1,7 @@
using System.ComponentModel;
-using Boyfriend.Data;
-using Boyfriend.Services;
using JetBrains.Annotations;
+using Octobot.Data;
+using Octobot.Services;
using Remora.Commands.Attributes;
using Remora.Commands.Groups;
using Remora.Discord.API.Abstractions.Objects;
@@ -15,7 +15,7 @@ using Remora.Discord.Gateway;
using Remora.Rest.Core;
using Remora.Results;
-namespace Boyfriend.Commands;
+namespace Octobot.Commands;
///
/// Handles the command to get the time taken for the gateway to respond to the last heartbeat: /ping
@@ -78,7 +78,7 @@ public class PingCommandGroup : CommandGroup
var latency = _client.Latency.TotalMilliseconds;
if (latency is 0)
{
// No heartbeat has occurred, estimate latency from local time and "Boyfriend is thinking..." message
var lastMessageResult = await _channelApi.GetChannelMessagesAsync(
channelId, limit: 1, ct: ct);
if (!lastMessageResult.IsDefined(out var lastMessage))
@@ -90,7 +90,7 @@ public class PingCommandGroup : CommandGroup
}
var embed = new EmbedBuilder().WithSmallTitle(currentUser.GetTag(), currentUser)
- .WithTitle($"Beep{Random.Shared.Next(1, 4)}".Localized())
+ .WithTitle($"Sound{Random.Shared.Next(1, 4)}".Localized())
.WithDescription($"{latency:F0}{Messages.Milliseconds}")
.WithColour(latency < 250 ? ColorsList.Green : latency < 500 ? ColorsList.Yellow : ColorsList.Red)
.WithCurrentTimestamp()
@@ -78,7 +78,7 @@ public class PingCommandGroup : CommandGroup
if (latency is 0)
{
- // No heartbeat has occurred, estimate latency from local time and "Boyfriend is thinking..." message
+ // No heartbeat has occurred, estimate latency from local time and "Octobot is thinking..." message
var lastMessageResult = await _channelApi.GetChannelMessagesAsync(
channelId, limit: 1, ct: ct);